@@ -9,11 +9,13 @@
 
 #pragma once
 
+#include "core/output.h"
 #include "kwin_export.h"
 
-#include <NETWM>
+#include "globals.h"
 
 #include <QObject>
+#include <QWindow>
 
 class QWindow;
 
@@ -146,7 +148,7 @@ class KWIN_EXPORT EffectWindow : public QObject
      * Returns the NETWM window type
      * See https://standards.freedesktop.org/wm-spec/wm-spec-latest.html .
      */
-    Q_PROPERTY(int windowType READ windowType)
+    Q_PROPERTY(int windowType READ windowTypeInt)
     /**
      * Whether this EffectWindow is managed by KWin (it has control over its placement and other
      * aspects, as opposed to override-redirect windows that are entirely handled by the application).
@@ -540,7 +542,11 @@ public:
      * Returns the NETWM window type
      * See https://standards.freedesktop.org/wm-spec/wm-spec-latest.html .
      */
-    NET::WindowType windowType() const;
+    WindowType windowType() const;
+    int windowTypeInt() const
+    {
+        return int(windowType());
+    }
     /**
      * Returns whether the window is managed by KWin (it has control over its placement and other
      * aspects, as opposed to override-redirect windows that are entirely handled by the application).
@@ -821,25 +827,9 @@ Q_SIGNALS:
     void windowDesktopsChanged(KWin::EffectWindow *window);
 
     /**
-     * The window @p w gets shown again. The window was previously
-     * initially shown with windowAdded and hidden with windowHidden.
-     *
-     * @see windowHidden
-     * @see windowAdded
+     * This signal is emitted when a window is hidden or shown.
      */
-    void windowShown(KWin::EffectWindow *w);
-
-    /**
-     * The window @p w got hidden but not yet closed.
-     * This can happen when a window is still being used and is supposed to be shown again
-     * with windowShown. On X11 an example is autohiding panels. On Wayland every
-     * window first goes through the window hidden state and might get shown again, or might
-     * get closed the normal way.
-     *
-     * @see windowShown
-     * @see windowClosed
-     */
-    void windowHidden(KWin::EffectWindow *w);
+    void windowHiddenChanged(KWin::EffectWindow *window);
 
 protected:
     friend EffectWindowVisibleRef;
