@@ -32,9 +32,11 @@ class WindowsRunner : public Plugin, protected QDBusContext
     Q_CLASSINFO("D-Bus Interface", "org.kde.KWin.WindowsRunner")
 public:
     explicit WindowsRunner();
-    ~WindowsRunner() override;
 
-    RemoteActions Actions();
+    RemoteActions Actions()
+    {
+        return {};
+    }
     RemoteMatches Match(const QString &searchTerm);
     void Run(const QString &id, const QString &actionId);
 
@@ -50,7 +52,7 @@ private:
         KeepAboveAction,
         KeepBelowAction,
         // Desktop related actions
-        ActivateDesktopAction
+        ActivateDesktopAction,
     };
 
     RemoteMatch desktopMatch(const VirtualDesktop *desktop, const WindowsRunnerAction action = ActivateDesktopAction, qreal relevance = 1.0) const;
