@@ -66,7 +66,7 @@ public:
 
     void close();
 
-    void recordFrame(const QRegion &damage, Contents contents = Content::Video);
+    void scheduleRecord(const QRegion &damage, Contents contents = Content::Video);
 
     void setCursorMode(ScreencastV1Interface::CursorMode mode, qreal scale, const QRectF &viewport);
 
@@ -98,6 +98,7 @@ private:
     spa_pod *buildFormat(struct spa_pod_builder *b, enum spa_video_format format, struct spa_rectangle *resolution,
                          struct spa_fraction *defaultFramerate, struct spa_fraction *minFramerate, struct spa_fraction *maxFramerate,
                          const QList<uint64_t> &modifiers, quint32 modifiersFlags);
+    void record(const QRegion &damage, Contents contents);
 
     std::optional<ScreenCastDmaBufTextureParams> testCreateDmaBuf(const QSize &size, quint32 format, const QList<uint64_t> &modifiers);
 
