@@ -243,9 +243,8 @@ void DataDeviceInterface::updateDragTarget(SurfaceInterface *surface, quint32 se
     }
 
     if (d->drag.surface) {
-        if (d->drag.surface->resource()) {
-            d->send_leave();
-        }
+        d->send_leave();
+
         if (d->drag.posConnection) {
             disconnect(d->drag.posConnection);
             d->drag.posConnection = QMetaObject::Connection();
@@ -307,6 +306,12 @@ void DataDeviceInterface::updateDragTarget(SurfaceInterface *surface, quint32 se
         if (d->drag.posConnection) {
             disconnect(d->drag.posConnection);
         }
+        if (d->drag.sourceActionConnection) {
+            disconnect(d->drag.sourceActionConnection);
+        }
+        if (d->drag.targetActionConnection) {
+            disconnect(d->drag.targetActionConnection);
+        }
         d->drag = DataDeviceInterfacePrivate::Drag();
     });
 
@@ -324,7 +329,7 @@ void DataDeviceInterface::updateDragTarget(SurfaceInterface *surface, quint32 se
             dragSource->dndAction(action);
         };
         d->drag.targetActionConnection = connect(offer, &DataOfferInterface::dragAndDropActionsChanged, dragSource, matchOffers);
-        d->drag.sourceActionConnection = connect(dragSource, &AbstractDataSource::supportedDragAndDropActionsChanged, dragSource, matchOffers);
+        d->drag.sourceActionConnection = connect(dragSource, &AbstractDataSource::supportedDragAndDropActionsChanged, offer, matchOffers);
     }
 }
 
