@@ -9,6 +9,12 @@
 */
 #pragma once
 
+#include "config-kwin.h"
+
+#if !KWIN_BUILD_X11
+#error Do not include on non-X11 builds
+#endif
+
 #include <memory>
 
 #include "xwayland_interface.h"
